NAME
Schema::Test - Test schema versions for DBIx::Class.
SYNOPSIS
use Schema::Test;
my $obj = Schema::Test->new(%params);
$obj->list_versions;
$obj->schema;
$obj->version;
METHODS
new
my $schema = Schema::Test->new(%args);
Constructor inherited from Schema::Abstract. The optional version parameter selects a schema version from share/versions.txt.
Returns Schema::Test instance.
list_versions
my @versions = $schema->list_versions;
Return sorted list of available schema versions.
Returns list of strings.
schema
my $schema_class = $schema->schema;
Return DBIx::Class schema class name for the selected version.
Returns string.
version
my $version = $schema->version;
Return selected schema version.
Returns string.
ERRORS
new():
Schema version has bad format.
Cannot load Schema module.
From Class::Utils::set_params():
Unknown parameter '%s'.
EXAMPLES
EXAMPLE1
use strict;
use warnings;
use Schema::Test;
my $schema = Schema::Test->new(version => '0.3.0');
print $schema->schema, "\n";
print $schema->version, "\n";
# Output:
# Schema::Test::0_3_0
# 0.3.0
DEPENDENCIES
File::Share, Schema::Abstract.
SEE ALSO
- Schema::Abstract
-
Base class for versioned schema wrappers.
REPOSITORY
https://github.com/michal-josef-spacek/Schema-Test
AUTHOR
Michal Josef Špaček <skim@cpan.org>
LICENSE AND COPYRIGHT
Copyright (c) 2022-2026 Michal Josef Špaček.
This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
VERSION
0.02